Crate axum_ws_rooms

Crate axum_ws_rooms 

Structs

RoomsManager
use in combination with Arc to share it between threads internally it uses RwLock so it can handle concurrent requests without a problem when a user connects to ws endpoint you have to call init_user and it gives you a guard that when dropped will remove user from all rooms
UserReceiverGuard

Enums

RoomError