Structs
- Rooms
Manager - use in combination with
Arcto share it between threads internally it usesRwLockso it can handle concurrent requests without a problem when a user connects to ws endpoint you have to callinit_userand it gives you a guard that when dropped will remove user from all rooms - User
Receiver Guard